@@ -305,7 +305,7 @@ def OptimizationProblem(Model):
                 if self.xVector:
                     if self.xNorm[0]:
                         xVal = denormalize(xVal, self.xL, self.xU)
-                    setattr(self.Model, self.x, xVal)
+                    setattr(self.Model, self.x[0], xVal)
                 else:
                     for i, xi in enumerate(xVal):
                         if self.xNorm[i]:
@@ -396,7 +396,7 @@ def OptimizationProblem(Model):
                 if self.xVector:
                     if self.xNorm[0]:
                         xVal = denormalize(xVal, self.xL, self.xU)
-                    setattr(self.Model, self.x, xVal)
+                    setattr(self.Model, self.x[0], xVal)
                 else:
                     for i, xi in enumerate(xVal):
                         if self.xNorm[i]:
@@ -538,7 +538,7 @@ def OptimizationProblem(Model):
                 """
                 import pyOpt
 
-                Alg = eval('pyOpt.' + self.Alg + '()')
+                Alg = eval('pyOpt.' + self.Alg.upper() + '()')
                 Problem = pyOpt.Optimization(self.ModelName, SysEq)
                 for i in range(self.nx):
                     Problem.addVar(
@@ -605,7 +605,6 @@ def OptimizationProblem(Model):
                 # Denormalization
                 self.xOpt = [None] * self.nx
                 self.xNormOpt = [None] * self.nx
-                # self.xNormOpt = copy.deepcopy(xOpt)
                 self.fNormOpt = fOpt
                 for i in range(self.nx):
                     if self.xNorm[i]:
